Changes
=======

2.0.0 (2026-02-03)
------------------

- Refactor package layout to use ``pyproject.toml`` and implicit namespace packages.
  [rnix]


1.5 (2025-10-28)
----------------

- Pin upper versions of dependencies.
  [rnix]


1.4 (2022-12-05)
----------------

- Release wheel.
  [rnix]

- Python 3.10 support.
  [rnix]


1.3 (2018-07-16)
----------------

- Python 3 support.
  [rnix]


1.2
---

- Use ``yafowil.utils.entry_point`` decorator.
  [rnix]


1.1.2
-----

- Docs
  [jensens]


1.1.1
-----

- Provide translate callable for pyramid. soft dependency
  [rnix, 2012-04-24]


1.1
---

- use entry point for registration of webob preprocessor. depend on YAFOWIL 1.3
  [jensens, 2012-03-19]


1.0
---

- made it work
  [jensens, rnix, et al, 2010-12-27]
